<?php

use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/


/*
 * if no pro performer, then redirect to /login
 * [Cell Number] [Password] field -> proLogInWithPassword -> /pro/dashboard
 * -> they are authenticated in... see the home dashboard... logout button to -> /login
 */


Route::get('login', 'LoginController@showLoginForm')->name('login');
Route::post('login', 'LoginController@login');
Route::post('logout', 'LoginController@logout')->name('logout');

Route::middleware('pro.auth')->group(function () {

    Route::get('/', 'HomeController@dashboard')->name('dashboard');

    Route::get('/new-patient', 'HomeController@newPatient')->name('new-patient');

    Route::get('/patients', 'HomeController@patients')->name('patients');

    Route::name('practice-management.')->prefix('practice-management')->group(function () {
        Route::get('rates', 'PracticeManagementController@rates')->name('rates');
        Route::get('dashboard', 'PracticeManagementController@dashboard')->name('dashboard');
        Route::get('previous-bills', 'PracticeManagementController@previousBills')->name('previousBills');
        Route::get('financial-transactions', 'PracticeManagementController@financialTransactions')->name('financialTransactions');
        Route::get('pending-bills-to-sign', 'PracticeManagementController@pendingBillsToSign')->name('pendingBillsToSign');
        Route::get('hr', 'PracticeManagementController@hr')->name('hr');
        Route::get('direct-deposit-settings', 'PracticeManagementController@directDepositSettings')->name('directDepositSettings');
        Route::get('w9', 'PracticeManagementController@w9')->name('w9');
        Route::get('contract', 'PracticeManagementController@contract')->name('contract');
    });

    Route::name('patients.view.')->prefix('patients/view/{patient}')->group(function () {
        Route::get('', 'PatientController@dashboard')->name('dashboard');
        Route::get('care-plan', 'PatientController@carePlan')->name('care-plan');
        Route::get('medications', 'PatientController@medications')->name('medications');
        Route::get('dx-and-focus-areas', 'PatientController@dxAndFocusAreas')->name('dx-and-focus-areas');
        Route::get('care-team', 'PatientController@careTeam')->name('care-team');
        Route::get('measurements', 'PatientController@measurements')->name('measurements');
        Route::get('labs-and-studies', 'PatientController@labsAndStudies')->name('labs-and-studies');
        Route::get('history', 'PatientController@history')->name('history');
        Route::get('immunizations', 'PatientController@immunizations')->name('immunizations');
        Route::get('allergies', 'PatientController@allergies')->name('allergies');
        Route::get('notes', 'PatientController@notes')->name('notes');
        Route::get('flowsheets', 'PatientController@flowSheets')->name('flowsheets');
        Route::get('demographics', 'PatientController@demographics')->name('demographics');
        Route::get('account', 'PatientController@account')->name('account');
        Route::get('care-checklist', 'PatientController@careChecklist')->name('care-checklist');
        Route::get('documents', 'PatientController@documents')->name('documents');
        Route::get('education', 'PatientController@education')->name('education');
        Route::get('messaging', 'PatientController@messaging')->name('messaging');
        Route::get('duplicate', 'PatientController@duplicate')->name('duplicate');
    });



});
